==> com.liferay.source.formatter-1.0.581-sources-commercial.jar: com/liferay/source/formatter/checks/JSPExceptionOrderCheck.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.source.formatter.checks;

import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.kernel.util.Validator;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Hugo Huijser
 */
public class JSPExceptionOrderCheck extends BaseFileCheck {

	@Override
	protected String doProcess(
		String fileName, String absolutePath, String content) {

		return _sortExceptions(content);
	}

	private String _sortExceptions(String content) {
		Matcher matcher = _exceptionsPattern.matcher(content);

		while (matcher.find()) {
			String match = matcher.group();

			String[] lines = StringUtil.splitLines(match);

			String previousException = null;
			String previousLine = null;

			for (String line : lines) {
				line = StringUtil.trim(line);

				int x = line.indexOf("<liferay-ui:error exception=\"<%=");

				int y = line.indexOf(".class %>", x);

				if (y == -1) {
					previousException = null;

					continue;
				}

				String currentException = line.substring(x, y);

				if (Validator.isNotNull(previousException) &&
					(previousException.compareToIgnoreCase(currentException) >
						0)) {

					String replacement = StringUtil.replaceFirst(
						match, previousLine, line);

					replacement = StringUtil.replaceLast(
						replacement, line, previousLine);

					return StringUtil.replaceFirst(
						content, match, replacement, matcher.start());
				}

				previousException = currentException;
				previousLine = line;
			}
		}

		return content;
	}

	private final Pattern _exceptionsPattern = Pattern.compile(
		"(^[\t]*<liferay-ui:error exception=\"<%=.*\n)+", Pattern.MULTILINE);

}

==> com.liferay.source.formatter-1.0.1177-sources-commercial.jar: com/liferay/source/formatter/checks/JSPExceptionOrderCheck.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.source.formatter.checks;

import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.kernel.util.Validator;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Hugo Huijser
 */
public class JSPExceptionOrderCheck extends BaseFileCheck {

	@Override
	protected String doProcess(
		String fileName, String absolutePath, String content) {

		return _sortExceptions(content);
	}

	private String _sortExceptions(String content) {
		Matcher matcher = _exceptionsPattern.matcher(content);

		while (matcher.find()) {
			String match = matcher.group();

			String[] lines = StringUtil.splitLines(match);

			String previousException = null;
			String previousLine = null;

			for (String line : lines) {
				line = StringUtil.trim(line);

				int x = line.indexOf("<liferay-ui:error exception=\"<%=");

				int y = line.indexOf(".class %>", x);

				if (y == -1) {
					previousException = null;

					continue;
				}

				String currentException = line.substring(x, y);

				if (Validator.isNotNull(previousException) &&
					(previousException.compareToIgnoreCase(currentException) >
						0)) {

					String replacement = StringUtil.replaceFirst(
						match, previousLine, line);

					replacement = StringUtil.replaceLast(
						replacement, line, previousLine);

					return StringUtil.replaceFirst(
						content, match, replacement, matcher.start());
				}

				previousException = currentException;
				previousLine = line;
			}
		}

		return content;
	}

	private static final Pattern _exceptionsPattern = Pattern.compile(
		"(^[\t]*<liferay-ui:error exception=\"<%=.*\n)+", Pattern.MULTILINE);

}
